/* Copyright (c) 2003 ActiveState Corp.
   See the file LICENSE.txt for licensing information. */

/* Feature status panel dialog.
 *
 * Usage:
 *  All dialog interaction is done via an object passed in and out as the first
 *  window argument: window.arguments[0]. All these arguments are optional.
 *      none
 *  On return window.arguments[0] has:
 *      none
 */

var log = getLoggingMgr().getLogger("dialogs.featureControlPanel");
//log.setLevel(LOG_DEBUG);

var gWidgets = {};
var gPrefs = null;
var gObserverSvc = null;
var gFeatureStatusObserver = null;
var gFeatureStatusSvc = null;


//---- internal support stuff

function FeatureStatusObserver() {};
FeatureStatusObserver.prototype.observe = function(subject, topic, data)
{
    try {
        log.info("observe(subject="+subject+", topic="+topic+
                 ", data="+data+")");

        // Observing (1) pref and (2) plain nsIObserver notifications.
        // Below we key on the notification "name", whose def'n
        // depends on the type of notification.
        var name;
        if (topic == "") {
            name = data;  // presumably this is a pref notification
        } else {
            name = topic; // a normal notification
        }


        switch (name) {
        case "feature_status_ready":
            var featureName = data;
            var featureStatus = subject;
            _updateFeatureControlPanel(featureName,
                                       featureStatus.status,
                                       featureStatus.reason);
            break;











        case "perlDefaultInterpreter":




            _requestFeatureStatus('Perl Debugging');
            _requestFeatureStatus('Perl Syntax Checking');
            break;
        case "phpDefaultInterpreter":
            _requestFeatureStatus('PHP Debugging');
            _requestFeatureStatus('PHP Syntax Checking');
        case "pythonDefaultInterpreter":



            _requestFeatureStatus('Python Debugging');
            _requestFeatureStatus('Python Syntax Checking');
        case "tclshDefaultInterpreter":
            _requestFeatureStatus('Tcl Syntax Checking');
            // fall through
        case "wishDefaultInterpreter":



            _requestFeatureStatus('Tcl Debugging');
            break;
        }
    } catch(ex) {
        log.exception(ex);
    }
}


// Make a request to determine the status of the given feature.
//
//    "featureName" identifies the feature to get the status for. It
//        defaults to all features.
//
function _requestFeatureStatus(featureName)
{
    try {
        if (typeof(featureName) == "undefined" || !featureName) featureName = "*";
        log.info("_requestFeatureStatus(featureName='"+featureName+"')");

        var dummy = new Object();
        if (featureName == "*") {
            var allFeatureNames = ["Perl Debugging", "Perl Syntax Checking",
                                   "PHP Debugging", "PHP Syntax Checking",
                                   "Python Debugging", "Python Syntax Checking",
                                   "Tcl Debugging", "Tcl Syntax Checking",




                                   ];
            for (var i = 0; i < allFeatureNames.length; i++) {
                try {
                    gObserverSvc.notifyObservers(dummy,
                        "feature_status_request", allFeatureNames[i]);
                } catch(ex) {
                    log.exception(ex, "Error requesting status for '"+
                                      allFeatureNames[i]+"' feature");
                }
            }
        } else {
            try {
                gObserverSvc.notifyObservers(dummy, "feature_status_request",
                                             featureName);
            } catch(ex) {
                log.exception(ex, "Error requesting status for '"+
                                  featureName+"' feature");
            }
        }
    } catch (ex) {
        log.exception(ex, "_requestFeatureStatus error");
    }
}


// Update status in the feature control panel.
//
//    "featureName" names the feature.
//    "status" is a string describing the feature's status.
//    "reason" (optional) is a reason describing why the feature is not
//        functional.
//
function _updateFeatureControlPanel(featureName, status, reason)
{
    log.info("_updateFeatureControlPanel");
    try {
        if (typeof(reason) == "undefined") {
            reason = null;
        }

        var widget = null;
        switch (featureName) {
        case "Perl Debugging":
            status = "Debugging: " + status;
            widget = gWidgets.perlDebuggingStatus;
            break;
        case "Perl Syntax Checking":
            status = "Syntax Checking: " + status;
            widget = gWidgets.perlSyntaxCheckingStatus;
            break;
        case "PHP Debugging":
            status = "Debugging: " + status;
            widget = gWidgets.phpDebuggingStatus;
            break;
        case "PHP Syntax Checking":
            status = "Syntax Checking: " + status;
            widget = gWidgets.phpSyntaxCheckingStatus;
            break;
        case "Python Debugging":
            status = "Debugging: " + status;
            widget = gWidgets.pythonDebuggingStatus;
            break;
        case "Python Syntax Checking":
            status = "Syntax Checking: " + status;
            widget = gWidgets.pythonSyntaxCheckingStatus;
            break;
        case "Tcl Debugging":
            status = "Debugging: " + status;
            widget = gWidgets.tclDebuggingStatus;
            break;
        case "Tcl Syntax Checking":
            status = "Syntax Checking: " + status;
            widget = gWidgets.tclSyntaxCheckingStatus;
            break;





























        }

        if (widget) {
            widget.setAttribute("value", status);
            if (reason) {
                widget.setAttribute("tooltip", "aTooltip");
                widget.setAttribute("tooltiptext", reason);
            } else {
                widget.removeAttribute("tooltip");
                widget.removeAttribute("tooltiptext");
            }
        }
    } catch (ex) {
        log.exception(ex, "_updateFeatureControlPanel error");
    }
}


//---- interface routines for XUL

function OnLoad()
{
    try {
        gWidgets.dialog = document.getElementById("dialog-featurecontrolpanel");
        gWidgets.cancelButton = gWidgets.dialog.getButton("cancel");
        gWidgets.perlDebuggingStatus = document.getElementById("perl-debugging-status");
        gWidgets.perlSyntaxCheckingStatus = document.getElementById("perl-syntax-checking-status");
        gWidgets.phpDebuggingStatus = document.getElementById("php-debugging-status");
        gWidgets.phpSyntaxCheckingStatus = document.getElementById("php-syntax-checking-status");
        gWidgets.pythonDebuggingStatus = document.getElementById("python-debugging-status");
        gWidgets.pythonSyntaxCheckingStatus = document.getElementById("python-syntax-checking-status");
        gWidgets.tclDebuggingStatus = document.getElementById("tcl-debugging-status");
        gWidgets.tclSyntaxCheckingStatus = document.getElementById("tcl-syntax-checking-status");










        gWidgets.cancelButton.setAttribute("label", "Close");
        gWidgets.cancelButton.setAttribute("accesskey", "C");

        gFeatureStatusObserver = new FeatureStatusObserver();
        gObserverSvc = Components.classes["@mozilla.org/observer-service;1"].
                           getService(Components.interfaces.nsIObserverService);
        gObserverSvc.addObserver(gFeatureStatusObserver, "feature_status_ready", false);
        gPrefs = Components.classes["@activestate.com/koPrefService;1"].
                        getService(Components.interfaces.koIPrefService).prefs;
        gPrefs.addObserver(gFeatureStatusObserver); //XXX may want to use pref-specific observers

        //XXX Doing this here results in feature_status_request's being observed
        //    once for every time this dialog was opened. I don't know why.
        //    Presumably because koFeatureStatusService.finalize() is not
        //    properly removing the observer. Workaround: do the .initialize()
        //    and .finalize() in jaguar.js.
        //gFeatureStatusSvc = Components.classes["@activestate.com/koFeatureStatusService;1"].
        //    getService(Components.interfaces.koIFeatureStatusService);
        //gFeatureStatusSvc.initialize();

        _requestFeatureStatus("*");

        window.sizeToContent();
    } catch(ex) {
        log.exception(ex, "Error loading feature status panel dialog.");
    }
}


function OnUnload()
{
    try {
        //XXX See note about re: gFeatureStatusSvc.
        //gFeatureStatusSvc.finalize();

        gPrefs.removeObserver(gFeatureStatusObserver);
        gObserverSvc.removeObserver(gFeatureStatusObserver, "feature_status_ready");
        delete gFeatureStatusObserver;
        gFeatureStatusObserver = null;
    } catch(ex) {
        log.exception(ex);
    }
}


function LaunchHelp(page)
{
    try {
        opener.launch_MainHelp(page);
    } catch(ex) {
        log.exception(ex);
    }
}


function LaunchPrefs(panel)
{
    try {
        opener.prefs_doGlobalPrefs(panel);
    } catch(ex) {
        log.exception(ex);
    }
}


function Cancel()
{
    try {
        return true;
    } catch(ex) {
        log.exception(ex);
    }
}


