/* Copyright (c) 2003 ActiveState Corp.
   See the file LICENSE.txt for licensing information. */

/* Source Code Control commit dialog.
 *
 * To use this dialog you should just call sccdialogs.js::dialog_commit().
 *
 * Usage:
 *  All dialog interaction is done via an object passed in and out as the first
 *  window argument: window.arguments[0].
 *      .urls           is the urls that are going to be committed. The URLs
 *                      are automatically converted for display via
 *                      uriparse_displayPath().
 *      .message        (optional) the default check-in message
 *  On return window.arguments[0] has:
 *      .retval         "OK" or "Cancel"
 *      .selected       (only iff .retval=="OK") a list of selected urls
 *      .message        the user's checkin message
 *
 * Dev Notes:
 *  This dialog is very similar in implementation to selectFromList.xul.
 */

var log = getLoggingMgr().getLogger("scc.commit");
//log.setLevel(LOG_DEBUG);

var gURLs = null;           // List of URLs from which the user can select.
var gDefaultMessage = null; // Store the original default message for later
                            // comparison.


var gURLTreeView = {  // The nsITreeView object for the list of URLs.
    getCellText : function(row, column) {
        var url = gURLs[row];
        return uriparse_displayPath(url);
    },
    rowCount : function() { return gURLs.length; },

    // Everything below here is just to satisfy the interface, and not all of it may
    // be required.
    tree : null,
    isSeparator : function(index) {return false;},
    isContainer : function(index) {return false;},
    setTree : function(out) { this.tree = out; },
    getRowProperties : function(row,prop){},
    getColumnProperties : function(column,prop){},
    getCellProperties : function(row,prop){},
    isContainer : function(row) {return false;},
    cycleCell: function(row, colId) {},
    setRowCount : function(rowCount) {
        this.rowCount = rowCount;
        this.tree.beginUpdateBatch();
        this.tree.rowCountChanged(0, this.rowCount);
        this.tree.invalidate();
        this.tree.endUpdateBatch();
    },
    selectionChanged : function() {},
    performAction : function(action) {},
    isSorted : function() {return true;},
    getImageSrc : function() {return null;},
    cycleHeader : function() {},
    /* our own defined methods */
    sort: function() {
    }
};


//---- interface routines for XUL

function OnLoad()
{
    var dialog = document.getElementById("dialog-commit");
    var okButton = dialog.getButton("accept");
    var cancelButton = dialog.getButton("cancel");
    okButton.setAttribute("accesskey", "o");
    cancelButton.setAttribute("accesskey", "c");

    // .title
    if (typeof window.arguments[0].title != "undefined" &&
        window.arguments[0].title != null) {
        window.title = window.arguments[0].title;
    } else {
        window.title = "Check-in to Source Control";
    }

    // .urls
    gURLs = window.arguments[0].urls;
    if (typeof gURLs == "undefined" || gURLs == null) {
        //XXX Is this the kind of error handling we want to do in onload
        //    handlers?
        var msg = "Internal Error: illegal 'urls' value for "
                  +"SCC Commit dialog: '"+gURLs+"'.";
        log.error(msg);
        alert(msg);
        window.close();
    }
    var urlsTree = document.getElementById("urls");
    if (gURLs.length > 20) { // get taller if there are a lot of urls
        addStyle(urlsTree, "min-height", "400px");
    }
    urlsTree.treeBoxObject.view = gURLTreeView;
    gURLTreeView.setRowCount(gURLs.length);

    // .message
    var messageTextbox = document.getElementById("message");
    var message = window.arguments[0].message;
    dump("XXX message is '"+message+"'\n");
    if (typeof message != "undefined" && message != null) {
        dump("XXX gDefaultMessage is '"+message+"'\n");
        gDefaultMessage = message;
        messageTextbox.value = message;
//        messageTextbox.setAttribute("value", message);
    } else {
        messageTextbox.value = "";
//        messageTextbox.setAttribute("value", "");
    }

    messageTextbox.focus();
    messageTextbox.setSelectionRange(0, messageTextbox.textLength);
    SelectAll();

    // Size to content before moving so "moveToAlertPosition" calculations are
    // correct.
    window.sizeToContent();
    dialog.moveToAlertPosition();
}


function OnSelectionChange()
{
    var dialog = document.getElementById("dialog-commit");
    var okButton = dialog.getButton("accept");
    if (gURLTreeView.selection.count == 0) {
        okButton.setAttribute("disabled", "true");
    } else if (okButton.hasAttribute("disabled")) {
        okButton.removeAttribute("disabled");
    }
}


function SelectAll()
{
    gURLTreeView.selection.selectAll();
    OnSelectionChange();
}


function ClearAll()
{
    gURLTreeView.selection.clearSelection();
    OnSelectionChange();
}


function OK()
{
    // Validate the message, i.e. encourage (but don't enforce) the user actual
    // enter something for a message.
    var messageTextbox = document.getElementById("message");
    var message = messageTextbox.value;
    var stripped = message.replace(/(^\s*|\s*$)/g, ''); // strip whitespace
    if (!stripped || (gDefaultMessage != null && message == gDefaultMessage)) {
        var prompt = "You have not entered a check-in message. " +
                     "Would you like to enter a message for this check-in?";
        var answer = dialog_yesNo(prompt, "Yes", null, null,
                                  "scc_no_commit_message");
        if (answer == "Yes") {
            messageTextbox.setSelectionRange(0, messageTextbox.textLength);
            messageTextbox.focus();
            return false;
        }
    }
    window.arguments[0].message = messageTextbox.value;

    // Get the list of selected urls.
    var selected = new Array();
    var i, item;
    for (i = 0; i < gURLs.length; ++i) {
        if (gURLTreeView.selection.isSelected(i)) {
            item = gURLs[i];
            selected.push(item);
        }
    }
    window.arguments[0].selected = selected;

    window.arguments[0].retval = "OK";
    return true;
}

function Cancel()
{
    window.arguments[0].retval = "Cancel";
    return true;
}

