#!/usr/bin/perl
# Copyright (c) 2000-2004 ActiveState Corp.

# This Perl program filters mail headers using a regular expression. This
# sample will show you how the Rx Toolkit can help you debug regular
# expressions.

use strict;
use Data::Dumper;

my %headers;
while (<DATA>) {
        if (/(.*):(.*)/) {
                $headers{$1} = $2;
        }
}
print Dumper \%headers;

# This code matches the "From" and "To" lines correctly; however, it does
# not correctly match all the mail headers.
#
# Run the script:
#   1. Press 'F7' to run without debugging; click "OK" to accept the default
#      options.
#
#   2. View the output in the Run Output tab. This script:
#      a) matched the initial "From sox@" line, which should have
#         been skipped; and
#      b) incorrectly matched the "Re" from the "Subject" header

# Now use the Rx Toolkit:
#   1. Select the regular expression above: (.*):(.*)
#
#   2. Select Tools|Rx Toolkit. Click the "Match All" mode button.
#
#   3. Enter a string to match the regular expression against (select the
#      text after the __DATA__ token at the end of this file).
#
#      a) The regular expression matched the first line, even though it's
#         not a valid email header, but the match is too broad. Narrow
#         the matches by requiring some whitespace after the colon. Edit
#         the the regular expression as follows:
#
#               (.*):\s+(.*)
#
#      b) "Re" from the "Subject" line matched as part of the first group
#         because there is another ":" after the "Re". Change the loaded
#         regular expression to:
#
#               (\w*):\s+(.*)
#
# Now paste the debugged regular expression back into your code.

# For more information on regular expressions and the Rx Toolkit, see
# "Introduction to Regular Expressions" and "Using the Rx Toolkit". Press
# 'F1', or select "Help" from the Help menu to view the Komodo User Guide.


__DATA__
From sox@laundry.com Wed Mar 28 12:02:04 2001
Date: Tue, 27 Mar 2001 14:48:53 -0800
From: Steven Sox <sox@laundry.com>
To: Eric Herrington <red@herring.com>
Subject: Re: are you done yet?

> When are you going to be finished your book, man? I've still only
> read the second draft. That was two months ago!

I finally finished it last night. Thanks so much for your support over
the last couple of months. This should be a best seller, "My Head Is
Shaped Like An Egg," by Steven Sox. Sounds good, eh?

One can always hope, anyway.

Later,
Steve.
